ActiveGroup class

Constructors

ActiveGroup({required String title, required String description, required int percentComplete, required int membersCount, required int goalAmount, required List<String> coins, required String rate})

Properties

coins ↔ List<String>
getter/setter pair
description → String
final
goalAmount → int
final
hashCode → int
The hash code for this object.
no setterinherited
membersCount → int
final
percentComplete → int
final
rate → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited