InitConfig class

Constructors

InitConfig({num? walletBalance, EventConfig? eventConfig, bool walletBalanceVisible = true, String primaryFiatCurrency = 'N'})
const

Properties

eventConfig → EventConfig?
final
hashCode → int
The hash code for this object.
no setterinherited
primaryFiatCurrency → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
walletBalance → num?
final
walletBalanceVisible → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited